@@ -33,6 +33,7 @@ import time
 import urllib2
 from BeautifulSoup import BeautifulSoup
 from urlparse import urljoin
+from calendar import timegm
 
 def getId(string):
     return md5.new(string).hexdigest()
@@ -121,8 +122,12 @@ class Feed:
                    entry["link"]
                except:
                    entry["link"] = ""
+               try:
+                   entry["author"]
+               except:
+                   entry["author"] = None
                tmpEntry = {"title":entry["title"], "content":self.extractContent(entry),
-                            "date":date, "link":entry["link"]}
+                            "date":date, "link":entry["link"], "author":entry["author"]}
                id = self.generateUniqueId(tmpEntry)
                
                #articleTime = time.mktime(self.entries[id]["dateTuple"])
@@ -148,6 +153,8 @@ class Feed:
                    self.db.execute("INSERT INTO feed (id, title, contentLink, date, updated, link, read) VALUES (?, ?, ?, ?, ?, ?, ?);", values)
                else:
                    try:
+                       self.db.execute("UPDATE feed SET updated=? WHERE id=?;", (currentTime, id) )
+                       self.db.commit()
                        filename = configdir+self.key+".d/"+id+".html"
                        file = open(filename,"a")
                        utime(filename, None)
@@ -162,35 +169,39 @@ class Feed:
            self.db.commit()
             
            
-           rows = self.db.execute("SELECT id FROM feed WHERE (read=0 AND updated<?) OR (read=1 AND updated<?);", (2*expiry, expiry))
-           for row in rows:
-               self.removeEntry(row[0])
-            
-           from glob import glob
-           from os import stat
-           for file in glob(configdir+self.key+".d/*"):
+        rows = self.db.execute("SELECT id FROM feed WHERE (read=0 AND updated<?) OR (read=1 AND updated<?);", (currentTime-2*expiry, currentTime-expiry))
+        for row in rows:
+           self.removeEntry(row[0])
+        
+        from glob import glob
+        from os import stat
+        for file in glob(configdir+self.key+".d/*"):
+            #
+            stats = stat(file)
+            #
+            # put the two dates into matching format
+            #
+            lastmodDate = stats[8]
+            #
+            expDate = time.time()-expiry*3
+            # check if image-last-modified-date is outdated
+            #
+            if expDate > lastmodDate:
                 #
-                stats = stat(file)
-                #
-                # put the two dates into matching format
-                #
-                lastmodDate = stats[8]
-                #
-                expDate = time.time()-expiry*3
-                # check if image-last-modified-date is outdated
-                #
-                if expDate > lastmodDate:
+                try:
                     #
-                    try:
-                        #
-                        #print 'Removing', file
-                        #
-                        remove(file) # commented out for testing
-                        #
-                    except OSError:
-                        #
-                        print 'Could not remove', file
-        return (currentTime, etag, modified)
+                    #print 'Removing', file
+                    #
+                    remove(file) # commented out for testing
+                    #
+                except OSError:
+                    #
+                    print 'Could not remove', file
+        updateTime = 0
+        rows = self.db.execute("SELECT MAX(date) FROM feed;")
+        for row in rows:
+            updateTime=row[0]
+        return (updateTime, etag, modified)
     
     def setEntryRead(self, id):
         self.db.execute("UPDATE feed SET read=1 WHERE id=?;", (id,) )
@@ -266,6 +277,7 @@ class Feed:
         content = entry["content"]
 
         link = entry['link']
+        author = entry['author']
         date = time.strftime("%a, %d %b %Y %H:%M:%S", time.localtime(entry["date"]) )
 
         #text = '''<div style="color: black; background-color: white;">'''
@@ -274,6 +286,8 @@ class Feed:
         text += '<meta http-equiv="Content-Type" content="text/html; charset=UTF-8"/>\n'
         #text += '<style> body {-webkit-user-select: none;} </style>'
         text += '</head><body><div><a href=\"' + link + '\">' + title + "</a>"
+        if author != None:
+            text += "<BR /><small><i>Author: " + author + "</i></small>"
         text += "<BR /><small><i>Date: " + date + "</i></small></div>"
         text += "<BR /><BR />"
         text += content
@@ -292,9 +306,9 @@ class Feed:
     
     def extractDate(self, entry):
         if entry.has_key("updated_parsed"):
-            return time.mktime(entry["updated_parsed"])
+            return timegm(entry["updated_parsed"])
         elif entry.has_key("published_parsed"):
-            return time.mktime(entry["published_parsed"])
+            return timegm(entry["published_parsed"])
         else:
             return 0
         
@@ -387,14 +401,14 @@ class Listing:
                 else:
                     self.addFeed("Maemo News", "http://maemo.org/news/items.xml")    
             else:
-                from string import find
-                if find(table[0], "widget")==-1:
+                from string import find, upper
+                if find(upper(table[0]), "WIDGET")<0:
                     self.db.execute("ALTER TABLE feeds ADD COLUMN (widget int);")
                     self.db.execute("UPDATE feeds SET widget=1;")
                     self.db.commit()
         except:
             pass
-        
+
     def importOldFormatFeeds(self):
         """This function loads feeds that are saved in an outdated format, and converts them to sqlite"""
         import rss
@@ -417,7 +431,7 @@ class Listing:
                             read_status = 1
                         else:
                             read_status = 0 
-                        date = time.mktime(feed.getDateTuple(item))
+                        date = timegm(feed.getDateTuple(item))
                         title = feed.getTitle(item)
                         newId = new_feed.generateUniqueId({"date":date, "title":title})
                         values = (newId, title , feed.getContentLink(item), date, time.time(), feed.getExternalLink(item), read_status)
